Learn R Programming

twoCoprimary (version 1.0.0)

print.twoCoprimary: Print Method for twoCoprimary Objects

Description

Provides a clean, formatted display of sample size and power calculation results from the twoCoprimary package.

Usage

# S3 method for twoCoprimary
print(x, ...)

Value

Invisibly returns the original object

Arguments

x

An object of class "twoCoprimary"

...

Additional arguments (currently unused)

Details

This print method provides a formatted output that displays key parameters and results in an easy-to-read format. The specific format adapts to the type of calculation (sample size vs power) and the type of endpoints involved.